#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.wncklet"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[4499]; const double alignment; void * const ptr;}  wncklet_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0160, 0001, 0000, 0000, 0000, 0000, 0000, 0050, 0014, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 
  0003, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 
  0007, 0000, 0000, 0000, 0012, 0000, 0000, 0000, 0013, 0000, 0000, 0000, 0014, 0000, 0000, 0000, 
  0000, 0113, 0055, 0223, 0003, 0000, 0000, 0000, 0160, 0001, 0000, 0000, 0006, 0000, 0114, 0000, 
  0170, 0001, 0000, 0000, 0174, 0001, 0000, 0000, 0002, 0006, 0071, 0371, 0011, 0000, 0000, 0000, 
  0174, 0001, 0000, 0000, 0033, 0000, 0166, 0000, 0230, 0001, 0000, 0000, 0377, 0001, 0000, 0000, 
  0327, 0256, 0115, 0101, 0011, 0000, 0000, 0000, 0377, 0001, 0000, 0000, 0024, 0000, 0166, 0000, 
  0030, 0002, 0000, 0000, 0161, 0002, 0000, 0000, 0201, 0321, 0040, 0031, 0006, 0000, 0000, 0000, 
  0161, 0002, 0000, 0000, 0005, 0000, 0114, 0000, 0170, 0002, 0000, 0000, 0174, 0002, 0000, 0000, 
  0311, 0275, 0351, 0223, 0011, 0000, 0000, 0000, 0174, 0002, 0000, 0000, 0016, 0000, 0166, 0000, 
  0220, 0002, 0000, 0000, 0064, 0011, 0000, 0000, 0265, 0144, 0045, 0040, 0000, 0000, 0000, 0000, 
  0064, 0011, 0000, 0000, 0007, 0000, 0114, 0000, 0074, 0011, 0000, 0000, 0100, 0011, 0000, 0000, 
  0113, 0120, 0220, 0013, 0007, 0000, 0000, 0000, 0100, 0011, 0000, 0000, 0004, 0000, 0114, 0000, 
  0104, 0011, 0000, 0000, 0110, 0011, 0000, 0000, 0324, 0265, 0002, 0000, 0377, 0377, 0377, 0377, 
  0110, 0011, 0000, 0000, 0001, 0000, 0114, 0000, 0114, 0011, 0000, 0000, 0120, 0011, 0000, 0000, 
  0130, 0046, 0006, 0027, 0011, 0000, 0000, 0000, 0120, 0011, 0000, 0000, 0024, 0000, 0166, 0000, 
  0150, 0011, 0000, 0000, 0305, 0011, 0000, 0000, 0034, 0103, 0041, 0102, 0005, 0000, 0000, 0000, 
  0305, 0011, 0000, 0000, 0010, 0000, 0114, 0000, 0320, 0011, 0000, 0000, 0350, 0011, 0000, 0000, 
  0315, 0174, 0045, 0231, 0011, 0000, 0000, 0000, 0350, 0011, 0000, 0000, 0025, 0000, 0166, 0000, 
  0000, 0012, 0000, 0000, 0355, 0020, 0000, 0000, 0376, 0023, 0201, 0114, 0011, 0000, 0000, 0000, 
  0355, 0020, 0000, 0000, 0024, 0000, 0166, 0000, 0010, 0021, 0000, 0000, 0222, 0021, 0000, 0000, 
  0160, 0141, 0156, 0145, 0154, 0057, 0000, 0000, 0005, 0000, 0000, 0000, 0167, 0157, 0162, 0153, 
  0163, 0160, 0141, 0143, 0145, 0055, 0163, 0167, 0151, 0164, 0143, 0150, 0145, 0162, 0055, 0155, 
  0145, 0156, 0165, 0056, 0170, 0155, 0154, 0000, 0270, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0263, 0311, 0115, 0315, 0053, 0315, 0054, 0111, 0315, 0125, 0310, 0113, 0314, 0115, 
  0265, 0125, 0012, 0110, 0114, 0117, 0055, 0122, 0010, 0050, 0112, 0115, 0113, 0055, 0112, 0315, 
  0113, 0116, 0055, 0126, 0360, 0004, 0112, 0052, 0051, 0044, 0046, 0227, 0144, 0346, 0347, 0101, 
  0345, 0221, 0244, 0225, 0024, 0364, 0355, 0270, 0154, 0260, 0032, 0342, 0221, 0232, 0123, 0200, 
  0115, 0067, 0110, 0034, 0217, 0066, 0307, 0244, 0374, 0322, 0022, 0154, 0372, 0300, 0022, 0140, 
  0215, 0100, 0000, 0000, 0060, 0156, 0075, 0332, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0167, 
  0151, 0156, 0144, 0157, 0167, 0055, 0155, 0145, 0156, 0165, 0055, 0155, 0145, 0156, 0165, 0056, 
  0170, 0155, 0154, 0000, 0000, 0000, 0000, 0000, 0205, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0263, 0311, 0115, 0315, 0053, 0315, 0054, 0111, 0315, 0125, 0310, 0113, 0314, 0115, 
  0265, 0125, 0012, 0317, 0314, 0113, 0311, 0057, 0367, 0005, 0012, 0052, 0170, 0244, 0346, 0024, 
  0050, 0170, 0002, 0245, 0224, 0024, 0022, 0223, 0113, 0062, 0363, 0363, 0220, 0145, 0101, 0222, 
  0112, 0012, 0372, 0166, 0134, 0066, 0270, 0015, 0160, 0114, 0312, 0057, 0055, 0301, 0151, 0002, 
  0130, 0026, 0154, 0004, 0027, 0000, 0131, 0036, 0056, 0025, 0000, 0050, 0165, 0165, 0141, 0171, 
  0051, 0155, 0141, 0164, 0145, 0057, 0000, 0000, 0000, 0000, 0000, 0000, 0167, 0151, 0156, 0144, 
  0157, 0167, 0055, 0154, 0151, 0163, 0164, 0056, 0165, 0151, 0000, 0000, 0000, 0000, 0000, 0000, 
  0300, 0145, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0355, 0135, 0133, 0163, 0332, 0070, 
  0024, 0176, 0357, 0257, 0320, 0352, 0165, 0207, 0020, 0234, 0264, 0333, 0335, 0011, 0356, 0244, 
  0155, 0232, 0166, 0172, 0235, 0204, 0316, 0076, 0152, 0204, 0055, 0260, 0066, 0102, 0362, 0112, 
  0062, 0046, 0235, 0375, 0361, 0053, 0333, 0204, 0030, 0060, 0006, 0137, 0022, 0102, 0106, 0157, 
  0200, 0165, 0216, 0245, 0043, 0175, 0347, 0362, 0111, 0066, 0147, 0157, 0146, 0023, 0006, 0246, 
  0104, 0052, 0052, 0170, 0037, 0366, 0216, 0216, 0041, 0040, 0334, 0023, 0076, 0345, 0343, 0076, 
  0374, 0071, 0370, 0320, 0171, 0015, 0337, 0270, 0057, 0316, 0176, 0353, 0164, 0300, 0045, 0341, 
  0104, 0142, 0115, 0174, 0020, 0123, 0035, 0200, 0061, 0303, 0076, 0001, 0047, 0107, 0216, 0163, 
  0324, 0003, 0235, 0216, 0151, 0104, 0271, 0046, 0162, 0204, 0075, 0342, 0276, 0000, 0340, 0114, 
  0222, 0177, 0043, 0052, 0211, 0002, 0214, 0016, 0373, 0160, 0254, 0157, 0176, 0207, 0367, 0067, 
  0112, 0304, 0140, 0067, 0155, 0047, 0206, 0377, 0020, 0117, 0003, 0217, 0141, 0245, 0372, 0360, 
  0122, 0337, 0174, 0232, 0340, 0061, 0201, 0200, 0372, 0175, 0110, 0223, 0217, 0075, 0230, 0264, 
  0063, 0055, 0103, 0051, 0102, 0042, 0365, 0055, 0340, 0170, 0102, 0372, 0160, 0112, 0025, 0035, 
  0062, 0002, 0335, 0201, 0214, 0310, 0131, 0367, 0356, 0152, 0161, 0143, 0017, 0163, 0064, 0022, 
  0136, 0244, 0240, 0373, 0001, 0063, 0265, 0265, 0075, 0365, 0004, 0107, 0311, 0107, 0350, 0006, 
  0204, 0205, 0235, 0241, 0024, 0261, 0042, 0162, 0131, 0354, 0254, 0233, 0165, 0176, 0267, 0161, 
  0070, 0173, 0036, 0107, 0114, 0271, 0057, 0342, 0216, 0307, 0304, 0252, 0130, 0371, 0070, 0336, 
  0123, 0314, 0304, 0070, 0033, 0210, 0306, 0352, 0206, 0121, 0245, 0321, 0134, 0234, 0022, 0205, 
  0374, 0354, 0172, 0073, 0375, 0035, 0012, 0351, 0023, 0211, 0142, 0352, 0353, 0000, 0272, 0057, 
  0267, 0065, 0327, 0124, 0033, 0313, 0001, 0055, 0061, 0127, 0014, 0153, 0154, 0354, 0330, 0207, 
  0267, 0304, 0334, 0355, 0357, 0164, 0264, 0340, 0213, 0351, 0054, 0370, 0041, 0311, 0210, 0110, 
  0263, 0256, 0211, 0332, 0252, 0360, 0066, 0044, 0050, 0060, 0053, 0031, 0272, 0134, 0310, 0011, 
  0146, 0153, 0002, 0136, 0100, 0231, 0237, 0175, 0116, 0304, 0231, 0131, 0357, 0201, 0140, 0246, 
  0323, 0335, 0171, 0203, 0156, 0256, 0105, 0326, 0032, 0244, 0310, 0340, 0230, 0165, 0322, 0257, 
  0146, 0312, 0207, 0142, 0006, 0027, 0072, 0326, 0054, 0376, 0326, 0134, 0115, 0315, 0235, 0231, 
  0266, 0223, 0064, 0167, 0026, 0355, 0053, 0256, 0240, 0072, 0263, 0122, 0044, 0043, 0044, 0045, 
  0134, 0143, 0155, 0360, 0013, 0335, 0151, 0062, 0367, 0336, 0272, 0165, 0212, 0004, 0125, 0210, 
  0075, 0343, 0116, 0240, 0353, 0024, 0266, 0056, 0266, 0020, 0366, 0222, 0033, 0041, 0054, 0011, 
  0316, 0015, 0274, 0320, 0130, 0221, 0326, 0202, 0257, 0232, 0054, 0047, 0357, 0054, 0051, 0250, 
  0141, 0275, 0272, 0026, 0134, 0137, 0056, 0333, 0106, 0221, 0015, 0041, 0161, 0070, 0150, 0230, 
  0375, 0260, 0052, 0271, 0336, 0023, 0206, 0207, 0204, 0025, 0102, 0000, 0175, 0064, 0212, 0066, 
  0165, 0254, 0266, 0045, 0266, 0130, 0243, 0216, 0250, 0117, 0106, 0070, 0142, 0272, 0272, 0260, 
  0044, 0036, 0241, 0323, 0304, 0007, 0335, 0151, 0050, 0235, 0214, 0102, 0007, 0231, 0172, 0151, 
  0067, 0213, 0064, 0125, 0004, 0043, 0105, 0120, 0304, 0015, 0356, 0031, 0345, 0133, 0115, 0226, 
  0367, 0260, 0313, 0112, 0261, 0167, 0143, 0300, 0261, 0375, 0166, 0144, 0026, 0142, 0356, 0327, 
  0030, 0340, 0210, 0062, 0126, 0103, 0054, 0024, 0212, 0146, 0130, 0077, 0056, 0033, 0126, 0141, 
  0377, 0227, 0134, 0140, 0023, 0044, 0370, 0202, 0223, 0126, 0220, 0360, 0156, 0075, 0350, 0075, 
  0063, 0050, 0004, 0130, 0075, 0031, 0034, 0071, 0026, 0107, 0005, 0070, 0352, 0265, 0201, 0243, 
  0042, 0003, 0024, 0017, 0276, 0326, 0300, 0153, 0014, 0172, 0155, 0300, 0246, 0063, 0050, 0111, 
  0243, 0240, 0113, 0270, 0277, 0263, 0324, 0066, 0063, 0025, 0230, 0150, 0315, 0074, 0353, 0056, 
  0246, 0044, 0267, 0112, 0222, 0252, 0336, 0136, 0123, 0203, 0325, 0011, 0232, 0232, 0374, 0312, 
  0010, 0135, 0276, 0377, 0214, 0176, 0174, 0377, 0364, 0155, 0160, 0161, 0205, 0276, 0176, 0037, 
  0174, 0372, 0376, 0015, 0175, 0075, 0277, 0376, 0014, 0376, 0003, 0005, 0127, 0076, 0232, 0157, 
  0371, 0313, 0157, 0177, 0016, 0006, 0346, 0347, 0037, 0127, 0027, 0327, 0327, 0005, 0277, 0137, 
  0135, 0174, 0271, 0070, 0277, 0276, 0110, 0257, 0354, 0332, 0257, 0055, 0051, 0171, 0343, 0174, 
  0261, 0064, 0147, 0354, 0275, 0156, 0234, 0131, 0345, 0047, 0374, 0017, 0370, 0070, 0256, 0277, 
  0262, 0233, 0250, 0144, 0255, 0122, 0213, 0275, 0052, 0225, 0052, 0064, 0132, 0261, 0341, 0276, 
  0144, 0341, 0064, 0061, 0135, 0032, 0131, 0173, 0260, 0110, 0256, 0201, 0375, 0232, 0332, 0260, 
  0132, 0016, 0220, 0057, 0010, 0337, 0011, 0123, 0156, 0160, 0135, 0125, 0371, 0014, 0063, 0072, 
  0056, 0317, 0210, 0346, 0202, 0130, 0153, 0111, 0115, 0342, 0102, 0124, 0161, 0203, 0174, 0223, 
  0271, 0362, 0230, 0320, 0161, 0240, 0041, 0230, 0142, 0026, 0245, 0250, 0143, 0076, 0354, 0156, 
  0120, 0337, 0055, 0327, 0277, 0051, 0112, 0226, 0107, 0312, 0106, 0321, 0262, 0101, 0304, 0254, 
  0235, 0175, 0226, 0104, 0316, 0215, 0131, 0150, 0125, 0020, 0234, 0047, 0063, 0076, 0061, 0153, 
  0045, 0003, 0002, 0276, 0373, 0172, 0020, 0140, 0170, 0052, 0021, 0145, 0043, 0130, 0311, 0110, 
  0243, 0020, 0373, 0176, 0346, 0352, 0235, 0255, 0362, 0033, 0047, 0156, 0007, 0327, 0377, 0047, 
  0334, 0044, 0330, 0160, 0326, 0332, 0230, 0271, 0126, 0102, 0102, 0263, 0320, 0260, 0233, 0221, 
  0213, 0015, 0175, 0205, 0175, 0052, 0362, 0205, 0233, 0012, 0104, 0214, 0274, 0110, 0112, 0063, 
  0002, 0044, 0223, 0253, 0260, 0114, 0143, 0025, 0077, 0176, 0035, 0040, 0343, 0306, 0063, 0062, 
  0123, 0201, 0221, 0024, 0023, 0060, 0277, 0021, 0210, 0205, 0274, 0111, 0006, 0273, 0223, 0271, 
  0133, 0231, 0367, 0206, 0025, 0140, 0313, 0065, 0131, 0153, 0145, 0126, 0271, 0052, 0137, 0342, 
  0030, 0031, 0373, 0233, 0365, 0250, 0205, 0254, 0242, 0253, 0054, 0060, 0355, 0026, 0240, 0132, 
  0011, 0124, 0055, 0004, 0254, 0306, 0201, 0153, 0207, 0000, 0266, 0065, 0220, 0265, 0017, 0131, 
  0314, 0130, 0353, 0160, 0135, 0105, 0053, 0106, 0214, 0335, 0103, 0125, 0131, 0254, 0076, 0115, 
  0254, 0256, 0353, 0032, 0113, 0021, 0205, 0320, 0135, 0367, 0355, 0026, 0374, 0025, 0270, 0236, 
  0166, 0301, 0137, 0156, 0324, 0022, 0341, 0047, 0125, 0043, 0324, 0111, 0216, 0167, 0066, 0166, 
  0365, 0022, 0141, 0357, 0054, 0143, 0125, 0346, 0141, 0177, 0144, 0375, 0135, 0206, 0235, 0171, 
  0170, 0244, 0203, 0150, 0062, 0344, 0230, 0062, 0145, 0211, 0226, 0332, 0104, 0313, 0351, 0263, 
  0040, 0132, 0006, 0213, 0245, 0140, 0151, 0026, 0113, 0263, 0324, 0244, 0131, 0116, 0055, 0315, 
  0162, 0140, 0064, 0113, 0357, 0225, 0345, 0131, 0036, 0231, 0147, 0271, 0017, 0272, 0017, 0121, 
  0273, 0345, 0324, 0003, 0301, 0101, 0040, 0246, 0253, 0307, 0340, 0154, 0315, 0146, 0371, 0025, 
  0313, 0257, 0154, 0203, 0152, 0100, 0175, 0362, 0160, 0120, 0105, 0037, 0215, 0172, 0140, 0241, 
  0372, 0114, 0350, 0225, 0325, 0165, 0142, 0341, 0157, 0031, 0226, 0347, 0304, 0260, 0264, 0123, 
  0035, 0274, 0264, 0325, 0301, 0001, 0125, 0007, 0101, 0301, 0201, 0253, 0047, 0137, 0034, 0074, 
  0174, 0116, 0277, 0312, 0376, 0070, 0160, 0277, 0201, 0272, 0221, 0177, 0326, 0102, 0060, 0115, 
  0103, 0244, 0311, 0114, 0027, 0346, 0051, 0013, 0126, 0010, 0244, 0347, 0311, 0000, 0345, 0040, 
  0244, 0063, 0302, 0324, 0021, 0230, 0363, 0106, 0130, 0205, 0211, 0201, 0144, 0122, 0220, 0231, 
  0106, 0214, 0201, 0041, 0001, 0023, 0114, 0115, 0211, 0146, 0302, 0265, 0177, 0124, 0267, 0153, 
  0233, 0163, 0247, 0225, 0076, 0375, 0145, 0203, 0355, 0201, 0345, 0332, 0327, 0041, 0345, 0371, 
  0124, 0173, 0221, 0075, 0041, 0105, 0177, 0021, 0244, 0314, 0145, 0170, 0270, 0331, 0357, 0004, 
  0317, 0020, 0043, 0174, 0234, 0234, 0276, 0074, 0251, 0337, 0227, 0120, 0041, 0046, 0274, 0033, 
  0024, 0143, 0311, 0123, 0217, 0326, 0154, 0155, 0334, 0077, 0367, 0264, 0031, 0354, 0341, 0254, 
  0256, 0172, 0312, 0303, 0310, 0104, 0245, 0110, 0232, 0065, 0150, 0146, 0201, 0233, 0371, 0254, 
  0137, 0312, 0170, 0214, 0116, 0206, 0050, 0171, 0164, 0161, 0347, 0264, 0161, 0135, 0211, 0351, 
  0002, 0221, 0324, 0153, 0066, 0225, 0051, 0351, 0014, 0135, 0347, 0370, 0330, 0372, 0030, 0233, 
  0320, 0357, 0061, 0241, 0167, 0354, 0226, 0151, 0273, 0317, 0145, 0324, 0074, 0217, 0336, 0353, 
  0331, 0175, 0322, 0332, 0373, 0244, 0047, 0317, 0142, 0237, 0364, 0062, 0241, 0175, 0214, 0241, 
  0354, 0056, 0251, 0335, 0045, 0255, 0311, 0203, 0070, 0226, 0007, 0071, 0264, 0135, 0122, 0307, 
  0356, 0222, 0076, 0336, 0056, 0051, 0067, 0153, 0117, 0242, 0224, 0137, 0157, 0173, 0333, 0345, 
  0133, 0242, 0032, 0244, 0252, 0357, 0116, 0271, 0332, 0035, 0027, 0273, 0071, 0152, 0011, 0233, 
  0152, 0010, 0305, 0221, 0026, 0017, 0002, 0320, 0313, 0074, 0062, 0101, 0034, 0020, 0016, 0120, 
  0172, 0356, 0034, 0320, 0344, 0315, 0104, 0023, 0252, 0211, 0157, 0001, 0173, 0140, 0133, 0244, 
  0153, 0376, 0334, 0072, 0200, 0275, 0261, 0051, 0155, 0071, 0000, 0026, 0343, 0133, 0365, 0060, 
  0061, 0372, 0074, 0325, 0155, 0203, 0264, 0305, 0374, 0363, 0306, 0274, 0143, 0031, 0124, 0373, 
  0320, 0311, 0076, 0030, 0324, 0223, 0175, 0062, 0250, 0047, 0226, 0101, 0255, 0303, 0240, 0116, 
  0050, 0067, 0331, 0357, 0057, 0342, 0243, 0171, 0104, 0104, 0131, 0004, 0075, 0150, 0112, 0365, 
  0212, 0050, 0023, 0157, 0214, 0315, 0300, 0327, 0273, 0341, 0315, 0217, 0025, 0330, 0207, 0120, 
  0054, 0275, 0132, 0227, 0136, 0075, 0261, 0364, 0352, 0241, 0321, 0253, 0247, 0226, 0136, 0175, 
  0074, 0172, 0165, 0042, 0246, 0004, 0335, 0307, 0223, 0166, 0253, 0267, 0314, 0245, 0023, 0240, 
  0305, 0342, 0065, 0037, 0310, 0276, 0347, 0303, 0122, 0255, 0226, 0152, 0255, 0211, 0126, 0057, 
  0300, 0174, 0114, 0356, 0061, 0364, 0160, 0170, 0345, 0030, 0151, 0263, 0262, 0355, 0153, 0171, 
  0016, 0226, 0164, 0051, 0362, 0354, 0326, 0003, 0330, 0223, 0153, 0226, 0167, 0171, 0022, 0274, 
  0313, 0351, 0301, 0276, 0121, 0270, 0312, 0373, 0164, 0133, 0170, 0065, 0360, 0362, 0030, 0227, 
  0377, 0241, 0041, 0373, 0247, 0200, 0116, 0114, 0375, 0061, 0321, 0213, 0022, 0173, 0371, 0147, 
  0040, 0211, 0012, 0005, 0127, 0246, 0067, 0235, 0344, 0310, 0136, 0356, 0015, 0375, 0246, 0076, 
  0317, 0267, 0334, 0052, 0177, 0014, 0335, 0334, 0133, 0315, 0013, 0245, 0127, 0176, 0124, 0313, 
  0177, 0321, 0161, 0326, 0315, 0375, 0317, 0312, 0377, 0044, 0313, 0217, 0004, 0000, 0050, 0165, 
  0165, 0141, 0171, 0051, 0141, 0160, 0160, 0154, 0145, 0164, 0057, 0000, 0011, 0000, 0000, 0000, 
  0157, 0162, 0147, 0057, 0003, 0000, 0000, 0000, 0057, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 
  0163, 0150, 0157, 0167, 0144, 0145, 0163, 0153, 0164, 0157, 0160, 0055, 0155, 0145, 0156, 0165, 
  0056, 0170, 0155, 0154, 0000, 0000, 0000, 0000, 0211, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0263, 0311, 0115, 0315, 0053, 0315, 0054, 0111, 0315, 0125, 0310, 0113, 0314, 0115, 
  0265, 0125, 0012, 0316, 0310, 0057, 0127, 0160, 0111, 0055, 0316, 0056, 0311, 0057, 0120, 0360, 
  0110, 0315, 0051, 0120, 0360, 0004, 0112, 0052, 0051, 0044, 0046, 0227, 0144, 0346, 0347, 0101, 
  0344, 0241, 0322, 0040, 0131, 0045, 0175, 0073, 0056, 0033, 0174, 0106, 0070, 0046, 0345, 0227, 
  0226, 0340, 0066, 0003, 0054, 0015, 0062, 0204, 0013, 0000, 0027, 0025, 0057, 0315, 0000, 0050, 
  0165, 0165, 0141, 0171, 0051, 0167, 0156, 0143, 0153, 0154, 0145, 0164, 0057, 0000, 0000, 0000, 
  0010, 0000, 0000, 0000, 0013, 0000, 0000, 0000, 0004, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 
  0001, 0000, 0000, 0000, 0012, 0000, 0000, 0000, 0167, 0157, 0162, 0153, 0163, 0160, 0141, 0143, 
  0145, 0055, 0163, 0167, 0151, 0164, 0143, 0150, 0145, 0162, 0056, 0165, 0151, 0000, 0000, 0000, 
  0057, 0123, 0000, 0000, 0001, 0000, 0000, 0000, 0170, 0332, 0355, 0134, 0155, 0123, 0333, 0070, 
  0020, 0376, 0336, 0137, 0241, 0323, 0327, 0233, 0024, 0222, 0136, 0073, 0067, 0235, 0220, 0016, 
  0155, 0351, 0313, 0264, 0245, 0035, 0102, 0257, 0037, 0075, 0212, 0275, 0211, 0125, 0024, 0311, 
  0047, 0313, 0004, 0146, 0356, 0307, 0237, 0144, 0207, 0340, 0020, 0305, 0257, 0002, 0002, 0370, 
  0133, 0142, 0151, 0127, 0332, 0135, 0075, 0217, 0327, 0132, 0331, 0303, 0067, 0027, 0163, 0206, 
  0316, 0101, 0306, 0124, 0360, 0003, 0334, 0177, 0276, 0217, 0021, 0160, 0137, 0004, 0224, 0317, 
  0016, 0360, 0317, 0323, 0017, 0275, 0277, 0361, 0233, 0321, 0263, 0341, 0037, 0275, 0036, 0372, 
  0010, 0034, 0044, 0121, 0020, 0240, 0005, 0125, 0041, 0232, 0061, 0022, 0000, 0172, 0361, 0174, 
  0060, 0170, 0276, 0217, 0172, 0075, 0335, 0211, 0162, 0005, 0162, 0112, 0174, 0030, 0075, 0103, 
  0150, 0050, 0341, 0337, 0204, 0112, 0210, 0021, 0243, 0223, 0003, 0074, 0123, 0147, 0177, 0342, 
  0353, 0201, 0214, 0030, 0336, 0113, 0373, 0211, 0311, 0157, 0360, 0025, 0362, 0031, 0211, 0343, 
  0003, 0374, 0121, 0235, 0175, 0236, 0223, 0031, 0140, 0104, 0203, 0003, 0114, 0315, 0317, 0076, 
  0066, 0375, 0164, 0317, 0110, 0212, 0010, 0244, 0272, 0104, 0234, 0314, 0341, 0000, 0237, 0323, 
  0230, 0116, 0030, 0340, 0321, 0251, 0114, 0140, 0270, 0167, 0325, 0152, 0357, 0354, 0023, 0356, 
  0115, 0205, 0237, 0304, 0170, 0364, 0201, 0260, 0270, 0264, 0077, 0365, 0005, 0367, 0314, 0117, 
  0074, 0012, 0201, 0105, 0275, 0211, 0024, 0213, 0030, 0344, 0272, 0330, 0160, 0057, 0233, 0174, 
  0065, 0073, 0006, 0367, 0154, 0307, 0202, 0362, 0100, 0054, 0172, 0076, 0023, 0067, 0305, 0212, 
  0355, 0070, 0014, 0176, 0047, 0261, 0232, 0003, 0127, 0231, 0061, 0074, 0231, 0173, 0306, 0033, 
  0036, 0271, 0156, 0260, 0017, 0316, 0304, 0002, 0044, 0036, 0365, 0313, 0046, 0231, 0104, 0121, 
  0332, 0357, 0125, 0131, 0307, 0163, 0302, 0022, 0250, 0240, 0060, 0126, 0020, 0171, 0224, 0373, 
  0022, 0262, 0331, 0225, 0012, 0104, 0072, 0076, 0153, 0002, 0373, 0155, 0075, 0264, 0020, 0362, 
  0054, 0216, 0064, 0030, 0334, 0373, 0351, 0305, 0103, 0365, 0323, 0173, 0112, 0230, 0230, 0145, 
  0076, 0062, 0232, 0244, 0267, 0224, 0245, 0332, 0113, 0101, 0326, 0350, 0146, 0331, 0117, 0204, 
  0014, 0264, 0372, 0005, 0015, 0124, 0210, 0107, 0057, 0313, 0272, 0053, 0252, 0064, 0000, 0221, 
  0222, 0204, 0307, 0214, 0050, 0242, 0341, 0170, 0200, 0057, 0101, 0217, 0366, 0353, 0052, 0214, 
  0150, 0254, 0131, 0317, 0017, 0101, 0242, 0037, 0022, 0246, 0040, 0065, 0113, 0102, 0134, 0252, 
  0367, 0062, 0002, 0057, 0244, 0306, 0123, 0134, 0310, 0071, 0141, 0033, 0002, 0176, 0110, 0131, 
  0200, 0122, 0346, 0344, 0204, 0365, 0322, 0277, 0072, 0176, 0023, 0161, 0261, 0364, 0204, 0315, 
  0217, 0157, 0165, 0153, 0352, 0304, 0314, 0147, 0075, 0323, 0275, 0277, 0352, 0137, 0223, 0141, 
  0232, 0270, 0333, 0046, 0043, 0044, 0325, 0113, 0202, 0050, 0315, 0357, 0170, 0164, 0156, 0202, 
  0352, 0157, 0332, 0153, 0135, 0204, 0332, 0275, 0372, 0166, 0203, 0107, 0003, 0153, 0157, 0273, 
  0207, 0210, 0157, 0006, 0362, 0210, 0004, 0222, 0063, 0334, 0352, 0254, 0104, 0051, 0301, 0157, 
  0272, 0054, 0047, 0337, 0137, 0123, 0320, 0300, 0173, 0115, 0075, 0170, 0155, 0336, 0372, 0265, 
  0355, 0126, 0144, 0046, 0230, 0033, 0222, 0067, 0311, 0056, 0334, 0224, 0264, 0220, 0013, 0231, 
  0000, 0263, 0256, 0155, 0357, 0223, 0126, 0264, 0155, 0142, 0215, 0075, 0121, 0342, 0215, 0046, 
  0242, 0001, 0114, 0111, 0302, 0124, 0175, 0141, 0011, 0076, 0320, 0163, 0103, 0056, 0127, 0032, 
  0012, 0203, 0141, 0275, 0201, 0246, 0167, 0361, 0121, 0226, 0211, 0324, 0021, 0114, 0142, 0360, 
  0022, 0256, 0131, 0210, 0121, 0136, 0352, 0262, 0074, 0157, 0256, 0053, 0045, 0376, 0231, 0006, 
  0107, 0371, 0160, 0160, 0021, 0021, 0036, 0064, 0060, 0160, 0112, 0031, 0153, 0040, 0026, 0211, 
  0230, 0146, 0130, 0337, 0057, 0062, 0313, 0072, 0377, 0341, 0236, 0145, 0325, 0067, 0101, 0102, 
  0040, 0070, 0070, 0101, 0302, 0273, 0315, 0244, 0350, 0221, 0101, 0041, 0044, 0361, 0316, 0340, 
  0150, 0320, 0341, 0310, 0202, 0243, 0276, 0013, 0034, 0331, 0034, 0140, 0067, 0276, 0221, 0341, 
  0015, 0214, 0336, 0114, 0041, 0375, 0063, 0317, 0044, 0106, 0170, 0004, 0074, 0250, 0054, 0125, 
  0106, 0067, 0026, 0027, 0155, 0270, 0147, 0223, 0142, 0354, 0271, 0325, 0175, 0346, 0003, 0365, 
  0022, 0331, 0326, 0311, 0130, 0141, 0102, 0326, 0037, 0264, 0115, 0133, 0076, 0110, 0363, 0350, 
  0231, 0162, 0365, 0324, 0374, 0354, 0343, 0273, 0241, 0326, 0332, 0060, 0204, 0163, 0355, 0057, 
  0055, 0370, 0361, 0375, 0027, 0357, 0307, 0367, 0317, 0307, 0247, 0107, 0047, 0336, 0267, 0357, 
  0247, 0237, 0277, 0037, 0173, 0337, 0016, 0307, 0137, 0320, 0177, 0310, 0322, 0362, 0111, 0377, 
  0313, 0067, 0277, 0375, 0171, 0172, 0252, 0057, 0377, 0070, 0071, 0032, 0217, 0055, 0327, 0117, 
  0216, 0276, 0036, 0035, 0216, 0217, 0322, 0226, 0072, 0163, 0113, 0357, 0133, 0336, 0005, 0141, 
  0164, 0126, 0174, 0273, 0265, 0204, 0062, 0044, 0372, 0231, 0177, 0011, 0067, 0256, 0357, 0226, 
  0205, 0302, 0326, 0240, 0332, 0003, 0173, 0150, 0046, 0163, 0375, 0304, 0113, 0256, 0376, 0016, 
  0260, 0115, 0276, 0105, 0220, 0333, 0006, 0172, 0327, 0203, 0155, 0015, 0070, 0114, 0225, 0027, 
  0221, 0040, 0050, 0101, 0141, 0171, 0340, 0252, 0162, 0234, 0263, 0120, 0271, 0010, 0127, 0153, 
  0102, 0253, 0104, 0156, 0257, 0052, 0111, 0027, 0172, 0326, 0356, 0335, 0023, 0022, 0120, 0221, 
  0317, 0122, 0375, 0104, 0112, 0075, 0171, 0117, 0160, 0166, 0351, 0111, 0323, 0212, 0213, 0064, 
  0326, 0111, 0134, 0307, 0241, 0130, 0240, 0124, 0061, 0122, 0041, 0240, 0345, 0110, 0150, 0265, 
  0371, 0124, 0305, 0106, 0047, 0061, 0157, 0231, 0352, 0072, 0116, 0076, 0235, 0345, 0223, 0305, 
  0252, 0002, 0111, 0026, 0036, 0345, 0201, 0136, 0213, 0112, 0310, 0166, 0272, 0146, 0122, 0044, 
  0021, 0036, 0021, 0306, 0362, 0133, 0207, 0351, 0152, 0251, 0246, 0162, 0133, 0352, 0133, 0055, 
  0015, 0166, 0222, 0022, 0073, 0110, 0217, 0133, 0247, 0312, 0025, 0322, 0346, 0322, 0107, 0321, 
  0266, 0014, 0120, 0314, 0257, 0167, 0201, 0267, 0126, 0176, 0256, 0220, 0377, 0325, 0367, 0122, 
  0105, 0256, 0264, 0255, 0177, 0134, 0246, 0267, 0076, 0143, 0352, 0141, 0256, 0111, 0062, 0106, 
  0224, 0277, 0256, 0152, 0251, 0263, 0350, 0071, 0144, 0314, 0133, 0140, 0115, 0307, 0314, 0351, 
  0232, 0075, 0253, 0321, 0135, 0165, 0312, 0163, 0106, 0173, 0216, 0250, 0317, 0011, 0375, 0125, 
  0244, 0300, 0112, 0064, 0330, 0006, 0344, 0345, 0164, 0170, 0127, 0240, 0152, 0035, 0203, 0172, 
  0331, 0143, 0075, 0307, 0331, 0235, 0067, 0216, 0050, 0317, 0023, 0344, 0252, 0372, 0032, 0353, 
  0006, 0134, 0105, 0247, 0103, 0327, 0072, 0346, 0054, 0233, 0272, 0174, 0261, 0324, 0122, 0151, 
  0156, 0075, 0133, 0106, 0347, 0023, 0317, 0034, 0143, 0250, 0005, 0043, 0273, 0062, 0075, 0077, 
  0220, 0324, 0157, 0142, 0170, 0125, 0372, 0252, 0107, 0141, 0105, 0064, 0346, 0042, 0070, 0031, 
  0223, 0271, 0320, 0324, 0210, 0314, 0152, 0020, 0132, 0145, 0122, 0153, 0213, 0317, 0257, 0131, 
  0246, 0141, 0240, 0231, 0355, 0323, 0350, 0005, 0353, 0371, 0202, 0355, 0030, 0064, 0153, 0063, 
  0137, 0275, 0254, 0312, 0240, 0264, 0255, 0166, 0003, 0161, 0072, 0275, 0304, 0043, 0037, 0114, 
  0261, 0267, 0255, 0272, 0112, 0373, 0145, 0273, 0000, 0114, 0047, 0241, 0151, 0230, 0143, 0024, 
  0103, 0163, 0160, 0337, 0320, 0174, 0202, 0111, 0136, 0245, 0352, 0310, 0255, 0205, 0321, 0135, 
  0272, 0370, 0224, 0266, 0043, 0006, 0167, 0265, 0035, 0121, 0354, 0324, 0002, 0341, 0355, 0202, 
  0133, 0205, 0226, 0007, 0157, 0314, 0132, 0274, 0142, 0376, 0152, 0245, 0201, 0233, 0167, 0304, 
  0256, 0044, 0340, 0242, 0044, 0260, 0175, 0103, 0143, 0171, 0056, 0255, 0124, 0043, 0121, 0112, 
  0322, 0111, 0242, 0040, 0336, 0272, 0274, 0126, 0135, 0226, 0243, 0056, 0200, 0316, 0102, 0205, 
  0121, 0172, 0236, 0320, 0024, 0043, 0131, 0220, 0235, 0332, 0265, 0255, 0260, 0142, 0375, 0265, 
  0127, 0340, 0275, 0227, 0362, 0353, 0226, 0037, 0035, 0127, 0362, 0033, 0025, 0131, 0163, 0133, 
  0147, 0151, 0275, 0265, 0053, 0267, 0076, 0356, 0162, 0153, 0277, 0343, 0326, 0256, 0334, 0372, 
  0264, 0313, 0255, 0135, 0261, 0245, 0301, 0126, 0305, 0215, 0067, 0024, 0266, 0247, 0167, 0017, 
  0160, 0217, 0166, 0173, 0252, 0164, 0234, 0314, 0047, 0040, 0221, 0230, 0242, 0234, 0361, 0257, 
  0167, 0250, 0044, 0322, 0142, 0013, 0304, 0301, 0366, 0107, 0127, 0122, 0171, 0060, 0045, 0025, 
  0133, 0125, 0040, 0207, 0347, 0212, 0265, 0201, 0207, 0120, 0307, 0274, 0131, 0017, 0260, 0276, 
  0127, 0325, 0152, 0256, 0115, 0053, 0002, 0216, 0252, 0001, 0335, 0036, 0127, 0267, 0307, 0325, 
  0035, 0271, 0151, 0233, 0005, 0346, 0162, 0233, 0025, 0103, 0244, 0357, 0275, 0126, 0113, 0156, 
  0166, 0072, 0105, 0334, 0236, 0320, 0134, 0277, 0235, 0310, 0211, 0067, 0257, 0221, 0313, 0334, 
  0342, 0241, 0270, 0071, 0207, 0271, 0340, 0324, 0067, 0147, 0326, 0147, 0240, 0131, 0073, 0307, 
  0330, 0112, 0002, 0170, 0347, 0024, 0026, 0115, 0225, 0327, 0314, 0152, 0272, 0115, 0350, 0235, 
  0001, 0350, 0330, 0227, 0202, 0061, 0010, 0176, 0245, 0157, 0241, 0333, 0221, 0032, 0247, 0175, 
  0152, 0102, 0065, 0114, 0367, 0050, 0075, 0363, 0271, 0001, 0210, 0323, 0127, 0222, 0367, 0037, 
  0303, 0251, 0327, 0265, 0255, 0044, 0312, 0157, 0373, 0331, 0360, 0124, 0043, 0363, 0037, 0015, 
  0314, 0215, 0155, 0304, 0025, 0144, 0037, 0111, 0076, 0251, 0204, 0140, 0212, 0106, 0236, 0202, 
  0013, 0125, 0302, 0251, 0307, 0146, 0121, 0266, 0031, 0053, 0004, 0242, 0051, 0065, 0366, 0126, 
  0176, 0250, 0237, 0072, 0331, 0337, 0176, 0216, 0201, 0201, 0237, 0301, 0276, 0321, 0241, 0005, 
  0023, 0355, 0361, 0112, 0307, 0336, 0035, 0327, 0153, 0167, 0042, 0263, 0152, 0203, 0315, 0372, 
  0307, 0140, 0266, 0323, 0366, 0213, 0335, 0246, 0355, 0167, 0041, 0370, 0153, 0257, 0334, 0256, 
  0163, 0266, 0247, 0304, 0154, 0306, 0300, 0355, 0373, 0014, 0253, 0041, 0120, 0166, 0137, 0320, 
  0313, 0037, 0305, 0025, 0253, 0134, 0017, 0201, 0332, 0037, 0343, 0013, 0015, 0117, 0051, 0323, 
  0372, 0353, 0301, 0102, 0166, 0041, 0111, 0344, 0032, 0262, 0207, 0214, 0255, 0143, 0326, 0014, 
  0202, 0210, 0024, 0172, 0115, 0166, 0310, 0355, 0220, 0273, 0113, 0310, 0175, 0331, 0035, 0324, 
  0051, 0070, 0250, 0323, 0025, 0223, 0157, 0365, 0240, 0316, 0352, 0301, 0042, 0356, 0216, 0352, 
  0064, 0315, 0312, 0135, 0237, 0324, 0031, 0354, 0306, 0067, 0067, 0352, 0174, 0111, 0242, 0334, 
  0344, 0332, 0233, 0270, 0345, 0337, 0316, 0130, 0067, 0161, 0255, 0161, 0230, 0175, 0112, 0253, 
  0227, 0155, 0367, 0255, 0026, 0324, 0372, 0145, 0044, 0041, 0216, 0004, 0217, 0365, 0154, 0172, 
  0375, 0176, 0366, 0115, 0305, 0345, 0207, 0173, 0364, 0152, 0314, 0367, 0054, 0225, 0337, 0307, 
  0243, 0334, 0147, 0177, 0254, 0322, 0067, 0056, 0306, 0371, 0157, 0255, 0255, 0364, 0107, 0114, 
  0103, 0061, 0324, 0060, 0001, 0271, 0267, 0141, 0326, 0265, 0275, 0303, 0275, 0334, 0147, 0055, 
  0377, 0007, 0151, 0154, 0065, 0006, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0167, 0151, 0156, 
  0144, 0157, 0167, 0055, 0154, 0151, 0163, 0164, 0055, 0155, 0145, 0156, 0165, 0056, 0170, 0155, 
  0154, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0045, 0001, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0263, 0311, 0115, 0315, 0053, 0315, 0054, 0111, 0315, 0125, 0310, 0113, 0314, 0115, 
  0265, 0125, 0012, 0111, 0054, 0316, 0316, 0311, 0054, 0056, 0121, 0010, 0256, 0054, 0006, 0211, 
  0372, 0346, 0347, 0145, 0226, 0344, 0027, 0051, 0170, 0002, 0071, 0112, 0012, 0211, 0311, 0045, 
  0231, 0371, 0171, 0010, 0125, 0020, 0105, 0120, 0065, 0112, 0012, 0372, 0166, 0134, 0066, 0305, 
  0251, 0005, 0211, 0105, 0211, 0100, 0056, 0210, 0203, 0313, 0360, 0200, 0242, 0324, 0264, 0324, 
  0242, 0324, 0274, 0344, 0324, 0142, 0034, 0046, 0043, 0251, 0200, 0230, 0213, 0313, 0050, 0217, 
  0324, 0234, 0002, 0034, 0146, 0200, 0244, 0360, 0153, 0166, 0114, 0312, 0057, 0055, 0301, 0241, 
  0033, 0054, 0007, 0326, 0316, 0005, 0000, 0232, 0237, 0147, 0211, 0000, 0050, 0165, 0165, 0141, 
  0171, 0051
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[4499]; const double alignment; void * const ptr;}  wncklet_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\160\001\000\000\000\000\000\050\014\000\000\000"
  "\000\000\000\000\001\000\000\000\001\000\000\000\002\000\000\000"
  "\003\000\000\000\003\000\000\000\006\000\000\000\006\000\000\000"
  "\007\000\000\000\012\000\000\000\013\000\000\000\014\000\000\000"
  "\000\113\055\223\003\000\000\000\160\001\000\000\006\000\114\000"
  "\170\001\000\000\174\001\000\000\002\006\071\371\011\000\000\000"
  "\174\001\000\000\033\000\166\000\230\001\000\000\377\001\000\000"
  "\327\256\115\101\011\000\000\000\377\001\000\000\024\000\166\000"
  "\030\002\000\000\161\002\000\000\201\321\040\031\006\000\000\000"
  "\161\002\000\000\005\000\114\000\170\002\000\000\174\002\000\000"
  "\311\275\351\223\011\000\000\000\174\002\000\000\016\000\166\000"
  "\220\002\000\000\064\011\000\000\265\144\045\040\000\000\000\000"
  "\064\011\000\000\007\000\114\000\074\011\000\000\100\011\000\000"
  "\113\120\220\013\007\000\000\000\100\011\000\000\004\000\114\000"
  "\104\011\000\000\110\011\000\000\324\265\002\000\377\377\377\377"
  "\110\011\000\000\001\000\114\000\114\011\000\000\120\011\000\000"
  "\130\046\006\027\011\000\000\000\120\011\000\000\024\000\166\000"
  "\150\011\000\000\305\011\000\000\034\103\041\102\005\000\000\000"
  "\305\011\000\000\010\000\114\000\320\011\000\000\350\011\000\000"
  "\315\174\045\231\011\000\000\000\350\011\000\000\025\000\166\000"
  "\000\012\000\000\355\020\000\000\376\023\201\114\011\000\000\000"
  "\355\020\000\000\024\000\166\000\010\021\000\000\222\021\000\000"
  "\160\141\156\145\154\057\000\000\005\000\000\000\167\157\162\153"
  "\163\160\141\143\145\055\163\167\151\164\143\150\145\162\055\155"
  "\145\156\165\056\170\155\154\000\270\000\000\000\001\000\000\000"
  "\170\332\263\311\115\315\053\315\054\111\315\125\310\113\314\115"
  "\265\125\012\110\114\117\055\122\010\050\112\115\113\055\112\315"
  "\113\116\055\126\360\004\112\052\051\044\046\227\144\346\347\101"
  "\345\221\244\225\024\364\355\270\154\260\032\342\221\232\123\200"
  "\115\067\110\034\217\066\307\244\374\322\022\154\372\300\022\140"
  "\215\100\000\000\060\156\075\332\000\050\165\165\141\171\051\167"
  "\151\156\144\157\167\055\155\145\156\165\055\155\145\156\165\056"
  "\170\155\154\000\000\000\000\000\205\000\000\000\001\000\000\000"
  "\170\332\263\311\115\315\053\315\054\111\315\125\310\113\314\115"
  "\265\125\012\317\314\113\311\057\367\005\012\052\170\244\346\024"
  "\050\170\002\245\224\024\022\223\113\062\363\363\220\145\101\222"
  "\112\012\372\166\134\066\270\015\160\114\312\057\055\301\151\002"
  "\130\026\154\004\027\000\131\036\056\025\000\050\165\165\141\171"
  "\051\155\141\164\145\057\000\000\000\000\000\000\167\151\156\144"
  "\157\167\055\154\151\163\164\056\165\151\000\000\000\000\000\000"
  "\300\145\000\000\001\000\000\000\170\332\355\135\133\163\332\070"
  "\024\176\357\257\320\352\165\207\020\234\264\333\335\011\356\244"
  "\155\232\166\172\235\204\316\076\152\204\055\260\066\102\362\112"
  "\062\046\235\375\361\053\333\204\030\060\006\137\022\102\106\157"
  "\200\165\216\245\043\175\347\362\111\066\147\157\146\023\006\246"
  "\104\052\052\170\037\366\216\216\041\040\334\023\076\345\343\076"
  "\374\071\370\320\171\015\337\270\057\316\176\353\164\300\045\341"
  "\104\142\115\174\020\123\035\200\061\303\076\001\047\107\216\163"
  "\324\003\235\216\151\104\271\046\162\204\075\342\276\000\340\114"
  "\222\177\043\052\211\002\214\016\373\160\254\157\176\207\367\067"
  "\112\304\140\067\155\047\206\377\020\117\003\217\141\245\372\360"
  "\122\337\174\232\340\061\201\200\372\175\110\223\217\075\230\264"
  "\063\055\103\051\102\042\365\055\340\170\102\372\160\112\025\035"
  "\062\002\335\201\214\310\131\367\356\152\161\143\017\163\064\022"
  "\136\244\240\373\001\063\265\265\075\365\004\107\311\107\350\006"
  "\204\205\235\241\024\261\042\162\131\354\254\233\165\176\267\161"
  "\070\173\036\107\114\271\057\342\216\307\304\252\130\371\070\336"
  "\123\314\304\070\033\210\306\352\206\121\245\321\134\234\022\205"
  "\374\354\172\073\375\035\012\351\023\211\142\352\353\000\272\057"
  "\267\065\327\124\033\313\001\055\061\127\014\153\154\354\330\207"
  "\267\304\334\355\357\164\264\340\213\351\054\370\041\311\210\110"
  "\263\256\211\332\252\360\066\044\050\060\053\031\272\134\310\011"
  "\146\153\002\136\100\231\237\175\116\304\231\131\357\201\140\246"
  "\323\335\171\203\156\256\105\326\032\244\310\340\230\165\322\257"
  "\146\312\207\142\006\027\072\326\054\376\326\134\115\315\235\231"
  "\266\223\064\167\026\355\053\256\240\072\263\122\044\043\044\045"
  "\134\143\155\360\013\335\151\062\367\336\272\165\212\004\125\210"
  "\075\343\116\240\353\024\266\056\266\020\366\222\033\041\054\011"
  "\316\015\274\320\130\221\326\202\257\232\054\047\357\054\051\250"
  "\141\275\272\026\134\137\056\333\106\221\015\041\161\070\150\230"
  "\375\260\052\271\336\023\206\207\204\025\102\000\175\064\212\066"
  "\165\254\266\045\266\130\243\216\250\117\106\070\142\272\272\260"
  "\044\036\241\323\304\007\335\151\050\235\214\102\007\231\172\151"
  "\067\213\064\125\004\043\105\120\304\015\356\031\345\133\115\226"
  "\367\260\313\112\261\167\143\300\261\375\166\144\026\142\356\327"
  "\030\340\210\062\126\103\054\024\212\146\130\077\056\033\126\141"
  "\377\227\134\140\023\044\370\202\223\126\220\360\156\075\350\075"
  "\063\050\004\130\075\031\034\071\026\107\005\070\352\265\201\243"
  "\042\003\024\017\276\326\300\153\014\172\155\300\246\063\050\111"
  "\243\240\113\270\277\263\324\066\063\025\230\150\315\074\353\056"
  "\246\044\267\112\222\252\336\136\123\203\325\011\232\232\374\312"
  "\010\135\276\377\214\176\174\377\364\155\160\161\205\276\176\037"
  "\174\372\376\015\175\075\277\376\014\376\003\005\127\076\232\157"
  "\371\313\157\177\016\006\346\347\037\127\027\327\327\005\277\137"
  "\135\174\271\070\277\276\110\257\354\332\257\055\051\171\343\174"
  "\261\064\147\354\275\156\234\131\345\047\374\017\370\070\256\277"
  "\262\233\250\144\255\122\213\275\052\225\052\064\132\261\341\276"
  "\144\341\064\061\135\032\131\173\260\110\256\201\375\232\332\260"
  "\132\016\220\057\010\337\011\123\156\160\135\125\371\014\063\072"
  "\056\317\210\346\202\130\153\111\115\342\102\124\161\203\174\223"
  "\271\362\230\320\161\240\041\230\142\026\245\250\143\076\354\156"
  "\120\337\055\327\277\051\112\226\107\312\106\321\262\101\304\254"
  "\235\175\226\104\316\215\131\150\125\020\234\047\063\076\061\153"
  "\045\003\002\276\373\172\020\140\170\052\021\145\043\130\311\110"
  "\243\020\373\176\346\352\235\255\362\033\047\156\007\327\377\047"
  "\334\044\330\160\326\332\230\271\126\102\102\263\320\260\233\221"
  "\213\015\175\205\175\052\362\205\233\012\104\214\274\110\112\063"
  "\002\044\223\253\260\114\143\025\077\176\035\040\343\306\063\062"
  "\123\201\221\024\023\060\277\021\210\205\274\111\006\273\223\271"
  "\133\231\367\206\025\140\313\065\131\153\145\126\271\052\137\342"
  "\030\031\373\233\365\250\205\254\242\253\054\060\355\026\240\132"
  "\011\124\055\004\254\306\201\153\207\000\266\065\220\265\017\131"
  "\314\130\353\160\135\105\053\106\214\335\103\125\131\254\076\115"
  "\254\256\353\032\113\021\205\320\135\367\355\026\374\025\270\236"
  "\166\301\137\156\324\022\341\047\125\043\324\111\216\167\066\166"
  "\365\022\141\357\054\143\125\346\141\177\144\375\135\206\235\171"
  "\170\244\203\150\062\344\230\062\145\211\226\332\104\313\351\263"
  "\040\132\006\213\245\140\151\026\113\263\324\244\131\116\055\315"
  "\162\140\064\113\357\225\345\131\036\231\147\271\017\272\017\121"
  "\273\345\324\003\301\101\040\246\253\307\340\154\315\146\371\025"
  "\313\257\154\203\152\100\175\362\160\120\105\037\215\172\140\241"
  "\372\114\350\225\325\165\142\341\157\031\226\347\304\260\264\123"
  "\035\274\264\325\301\001\125\007\101\301\201\253\047\137\034\074"
  "\174\116\277\312\376\070\160\277\201\272\221\177\326\102\060\115"
  "\103\244\311\114\027\346\051\013\126\010\244\347\311\000\345\040"
  "\244\063\302\324\021\230\363\106\130\205\211\201\144\122\220\231"
  "\106\214\201\041\001\023\114\115\211\146\302\265\177\124\267\153"
  "\233\163\247\225\076\375\145\203\355\201\345\332\327\041\345\371"
  "\124\173\221\075\041\105\177\021\244\314\145\170\270\331\357\004"
  "\317\020\043\174\234\234\276\074\251\337\227\120\041\046\274\033"
  "\024\143\311\123\217\326\154\155\334\077\367\264\031\354\341\254"
  "\256\172\312\303\310\104\245\110\232\065\150\146\201\233\371\254"
  "\137\312\170\214\116\206\050\171\164\161\347\264\161\135\211\351"
  "\002\221\324\153\066\225\051\351\014\135\347\370\330\372\030\233"
  "\320\357\061\241\167\354\226\151\273\317\145\324\074\217\336\353"
  "\331\175\322\332\373\244\047\317\142\237\364\062\241\175\214\241"
  "\354\056\251\335\045\255\311\203\070\226\007\071\264\135\122\307"
  "\356\222\076\336\056\051\067\153\117\242\224\137\157\173\333\345"
  "\133\242\032\244\252\357\116\271\332\035\027\273\071\152\011\233"
  "\152\010\305\221\026\017\002\320\313\074\062\101\034\020\016\120"
  "\172\356\034\320\344\315\104\023\252\211\157\001\173\140\133\244"
  "\153\376\334\072\200\275\261\051\155\071\000\026\343\133\365\060"
  "\061\372\074\325\155\203\264\305\374\363\306\274\143\031\124\373"
  "\320\311\076\030\324\223\175\062\250\047\226\101\255\303\240\116"
  "\050\067\331\357\057\342\243\171\104\104\131\004\075\150\112\365"
  "\212\050\023\157\214\315\300\327\273\341\315\217\025\330\207\120"
  "\054\275\132\227\136\075\261\364\352\241\321\253\247\226\136\175"
  "\074\172\165\042\246\004\335\307\223\166\253\267\314\245\023\240"
  "\305\342\065\037\310\276\347\303\122\255\226\152\255\211\126\057"
  "\300\174\114\356\061\364\160\170\345\030\151\263\262\355\153\171"
  "\016\226\164\051\362\354\326\003\330\223\153\226\167\171\022\274"
  "\313\351\301\276\121\270\312\373\164\133\170\065\360\362\030\227"
  "\377\241\041\373\247\200\116\114\375\061\321\213\022\173\371\147"
  "\040\211\012\005\127\246\067\235\344\310\136\356\015\375\246\076"
  "\317\267\334\052\177\014\335\334\133\315\013\245\127\176\124\313"
  "\177\321\161\326\315\375\317\312\377\044\313\217\004\000\050\165"
  "\165\141\171\051\141\160\160\154\145\164\057\000\011\000\000\000"
  "\157\162\147\057\003\000\000\000\057\000\000\000\006\000\000\000"
  "\163\150\157\167\144\145\163\153\164\157\160\055\155\145\156\165"
  "\056\170\155\154\000\000\000\000\211\000\000\000\001\000\000\000"
  "\170\332\263\311\115\315\053\315\054\111\315\125\310\113\314\115"
  "\265\125\012\316\310\057\127\160\111\055\316\056\311\057\120\360"
  "\110\315\051\120\360\004\112\052\051\044\046\227\144\346\347\101"
  "\344\241\322\040\131\045\175\073\056\033\174\106\070\046\345\227"
  "\226\340\066\003\054\015\062\204\013\000\027\025\057\315\000\050"
  "\165\165\141\171\051\167\156\143\153\154\145\164\057\000\000\000"
  "\010\000\000\000\013\000\000\000\004\000\000\000\002\000\000\000"
  "\001\000\000\000\012\000\000\000\167\157\162\153\163\160\141\143"
  "\145\055\163\167\151\164\143\150\145\162\056\165\151\000\000\000"
  "\057\123\000\000\001\000\000\000\170\332\355\134\155\123\333\070"
  "\020\376\336\137\241\323\327\233\024\222\136\073\067\235\220\016"
  "\155\351\313\264\245\035\102\257\037\075\212\275\211\125\024\311"
  "\047\313\004\146\356\307\237\144\207\340\020\305\257\002\002\370"
  "\133\142\151\127\332\135\075\217\327\132\331\303\067\027\163\206"
  "\316\101\306\124\360\003\334\177\276\217\021\160\137\004\224\317"
  "\016\360\317\323\017\275\277\361\233\321\263\341\037\275\036\372"
  "\010\034\044\121\020\240\005\125\041\232\061\022\000\172\361\174"
  "\060\170\276\217\172\075\335\211\162\005\162\112\174\030\075\103"
  "\150\050\341\337\204\112\210\021\243\223\003\074\123\147\177\342"
  "\353\201\214\030\336\113\373\211\311\157\360\025\362\031\211\343"
  "\003\374\121\235\175\236\223\031\140\104\203\003\114\315\317\076"
  "\066\375\164\317\110\212\010\244\272\104\234\314\341\000\237\323"
  "\230\116\030\340\321\251\114\140\270\167\325\152\357\354\023\356"
  "\115\205\237\304\170\364\201\260\270\264\077\365\005\367\314\117"
  "\074\012\201\105\275\211\024\213\030\344\272\330\160\057\233\174"
  "\065\073\006\367\154\307\202\362\100\054\172\076\023\067\305\212"
  "\355\070\014\176\047\261\232\003\127\231\061\074\231\173\306\033"
  "\036\271\156\260\017\316\304\002\044\036\365\313\046\231\104\121"
  "\332\357\125\131\307\163\302\022\250\240\060\126\020\171\224\373"
  "\022\262\331\225\012\104\072\076\153\002\373\155\075\264\020\362"
  "\054\216\064\030\334\373\351\305\103\365\323\173\112\230\230\145"
  "\076\062\232\244\267\224\245\332\113\101\326\350\146\331\117\204"
  "\014\264\372\005\015\124\210\107\057\313\272\053\252\064\000\221"
  "\222\204\307\214\050\242\341\170\200\057\101\217\366\353\052\214"
  "\150\254\131\317\017\101\242\037\022\246\040\065\113\102\134\252"
  "\367\062\002\057\244\306\123\134\310\071\141\033\002\176\110\131"
  "\200\122\346\344\204\365\322\277\072\176\023\161\261\364\204\315"
  "\217\157\165\153\352\304\314\147\075\323\275\277\352\137\223\141"
  "\232\270\333\046\043\044\325\113\202\050\315\357\170\164\156\202"
  "\352\157\332\153\135\204\332\275\372\166\203\107\003\153\157\273"
  "\207\210\157\006\362\210\004\222\063\334\352\254\104\051\301\157"
  "\272\054\047\337\137\123\320\300\173\115\075\170\155\336\372\265"
  "\355\126\144\046\230\033\222\067\311\056\334\224\264\220\013\231"
  "\000\263\256\155\357\223\126\264\155\142\215\075\121\342\215\046"
  "\242\001\114\111\302\124\175\141\011\076\320\163\103\056\127\032"
  "\012\203\141\275\201\246\167\361\121\226\211\324\021\114\142\360"
  "\022\256\131\210\121\136\352\262\074\157\256\053\045\376\231\006"
  "\107\371\160\160\021\021\036\064\060\160\112\031\153\040\026\211"
  "\230\146\130\337\057\062\313\072\377\341\236\145\325\067\101\102"
  "\040\070\070\101\302\273\315\244\350\221\101\041\044\361\316\340"
  "\150\320\341\310\202\243\276\013\034\331\034\140\067\276\221\341"
  "\015\214\336\114\041\375\063\317\044\106\170\004\074\250\054\125"
  "\106\067\026\027\155\270\147\223\142\354\271\325\175\346\003\365"
  "\022\331\326\311\130\141\102\326\037\264\115\133\076\110\363\350"
  "\231\162\365\324\374\354\343\273\241\326\332\060\204\163\355\057"
  "\055\370\361\375\027\357\307\367\317\307\247\107\047\336\267\357"
  "\247\237\277\037\173\337\016\307\137\320\177\310\322\362\111\377"
  "\313\067\277\375\171\172\252\057\377\070\071\032\217\055\327\117"
  "\216\276\036\035\216\217\322\226\072\163\113\357\133\336\005\141"
  "\164\126\174\273\265\204\062\044\372\231\177\011\067\256\357\226"
  "\205\302\326\240\332\003\173\150\046\163\375\304\113\256\376\016"
  "\260\115\276\105\220\333\006\172\327\203\155\015\070\114\225\027"
  "\221\040\050\101\141\171\340\252\162\234\263\120\271\010\127\153"
  "\102\253\104\156\257\052\111\027\172\326\356\335\023\022\120\221"
  "\317\122\375\104\112\075\171\117\160\166\351\111\323\212\213\064"
  "\326\111\134\307\241\130\240\124\061\122\041\240\345\110\150\265"
  "\371\124\305\106\047\061\157\231\352\072\116\076\235\345\223\305"
  "\252\002\111\026\036\345\201\136\213\112\310\166\272\146\122\044"
  "\021\036\021\306\362\133\207\351\152\251\246\162\133\352\133\055"
  "\015\166\222\022\073\110\217\133\247\312\025\322\346\322\107\321"
  "\266\014\120\314\257\167\201\267\126\176\256\220\377\325\367\122"
  "\105\256\264\255\177\134\246\267\076\143\352\141\256\111\062\106"
  "\224\277\256\152\251\263\350\071\144\314\133\140\115\307\314\351"
  "\232\075\253\321\135\165\312\163\106\173\216\250\317\011\375\125"
  "\244\300\112\064\330\006\344\345\164\170\127\240\152\035\203\172"
  "\331\143\075\307\331\235\067\216\050\317\023\344\252\372\032\353"
  "\006\134\105\247\103\327\072\346\054\233\272\174\261\324\122\151"
  "\156\075\133\106\347\023\317\034\143\250\005\043\273\062\075\077"
  "\220\324\157\142\170\125\372\252\107\141\105\064\346\042\070\031"
  "\223\271\320\324\210\314\152\020\132\145\122\153\213\317\257\131"
  "\246\141\240\231\355\323\350\005\353\371\202\355\030\064\153\063"
  "\137\275\254\312\240\264\255\166\003\161\072\275\304\043\037\114"
  "\261\267\255\272\112\373\145\273\000\114\047\241\151\230\143\024"
  "\103\163\160\337\320\174\202\111\136\245\352\310\255\205\321\135"
  "\272\370\224\266\043\006\167\265\035\121\354\324\002\341\355\202"
  "\133\205\226\007\157\314\132\274\142\376\152\245\201\233\167\304"
  "\256\044\340\242\044\260\175\103\143\171\056\255\124\043\121\112"
  "\322\111\242\040\336\272\274\126\135\226\243\056\200\316\102\205"
  "\121\172\236\320\024\043\131\220\235\332\265\255\260\142\375\265"
  "\127\340\275\227\362\353\226\037\035\127\362\033\025\131\163\133"
  "\147\151\275\265\053\267\076\356\162\153\277\343\326\256\334\372"
  "\264\313\255\135\261\245\301\126\305\215\067\024\266\247\167\017"
  "\160\217\166\173\252\164\234\314\047\040\221\230\242\234\361\257"
  "\167\250\044\322\142\013\304\301\366\107\127\122\171\060\045\025"
  "\133\125\040\207\347\212\265\201\207\120\307\274\131\017\260\276"
  "\127\325\152\256\115\053\002\216\252\001\335\036\127\267\307\325"
  "\035\271\151\233\005\346\162\233\025\103\244\357\275\126\113\156"
  "\166\072\105\334\236\320\134\277\235\310\211\067\257\221\313\334"
  "\342\241\270\071\207\271\340\324\067\147\326\147\240\131\073\307"
  "\330\112\002\170\347\024\026\115\225\327\314\152\272\115\350\235"
  "\001\350\330\227\202\061\010\176\245\157\241\333\221\032\247\175"
  "\152\102\065\114\367\050\075\363\271\001\210\323\127\222\367\037"
  "\303\251\327\265\255\044\312\157\373\331\360\124\043\363\037\015"
  "\314\215\155\304\025\144\037\111\076\251\204\140\212\106\236\202"
  "\013\125\302\251\307\146\121\266\031\053\004\242\051\065\366\126"
  "\176\250\237\072\331\337\176\216\201\201\237\301\276\321\241\005"
  "\023\355\361\112\307\336\035\327\153\167\042\263\152\203\315\372"
  "\307\140\266\323\366\213\335\246\355\167\041\370\153\257\334\256"
  "\163\266\247\304\154\306\300\355\373\014\253\041\120\166\137\320"
  "\313\037\305\025\253\134\017\201\332\037\343\013\015\117\051\323"
  "\372\353\301\102\166\041\111\344\032\262\207\214\255\143\326\014"
  "\202\210\024\172\115\166\310\355\220\273\113\310\175\331\035\324"
  "\051\070\250\323\025\223\157\365\240\316\352\301\042\356\216\352"
  "\064\315\312\135\237\324\031\354\306\067\067\352\174\111\242\334"
  "\344\332\233\270\345\337\316\130\067\161\255\161\230\175\112\253"
  "\227\155\367\255\026\324\372\145\044\041\216\004\217\365\154\172"
  "\375\176\366\115\305\345\207\173\364\152\314\367\054\225\337\307"
  "\243\334\147\177\254\322\067\056\306\371\157\255\255\364\107\114"
  "\103\061\324\060\001\271\267\141\326\265\275\303\275\334\147\055"
  "\377\007\151\154\065\006\000\050\165\165\141\171\051\167\151\156"
  "\144\157\167\055\154\151\163\164\055\155\145\156\165\056\170\155"
  "\154\000\000\000\000\000\000\000\045\001\000\000\001\000\000\000"
  "\170\332\263\311\115\315\053\315\054\111\315\125\310\113\314\115"
  "\265\125\012\111\054\316\316\311\054\056\121\010\256\054\006\211"
  "\372\346\347\145\226\344\027\051\170\002\071\112\012\211\311\045"
  "\231\371\171\010\125\020\105\120\065\112\012\372\166\134\066\305"
  "\251\005\211\105\211\100\056\210\203\313\360\200\242\324\264\324"
  "\242\324\274\344\324\142\034\046\043\251\200\230\213\313\050\217"
  "\324\234\002\034\146\200\244\360\153\166\114\312\057\055\301\241"
  "\033\054\007\326\316\005\000\232\237\147\211\000\050\165\165\141"
  "\171\051" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { wncklet_resource_data.data, sizeof (wncklet_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *wncklet_get_resource (void);
GResource *wncklet_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
